@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_CERTIFICATERESOLVER_H__
-#define __KLEOPATRA_CRYPTO_CERTIFICATERESOLVER_H__
+#pragma once
 
 #include <utils/pimpl_ptr.h>
 
@@ -87,4 +86,3 @@ public:
 }
 }
 
-#endif /* __KLEOPATRA_UISERVER_CERTIFICATERESOLVER_H__ */
