@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_SIGNERRESOLVEPAGE_H__
-#define __KLEOPATRA_CRYPTO_GUI_SIGNERRESOLVEPAGE_H__
+#pragma once
 
 #include <crypto/gui/wizardpage.h>
 
@@ -122,5 +121,4 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_CRYPTO_GUI_SIGNERRESOLVEPAGE_H__
 
