@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__
-#define __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__
+#pragma once
 
 #include <QDialog>
 
@@ -49,4 +48,3 @@ private:
 }
 }
 
-#endif /* __KLEOPATRA_DIALOGS_ADDUSERIDDIALOG_H__ */
