@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_DIALOGS_CERTIFYCERTIFICATEDIALOG_H__
-#define __KLEOPATRA_DIALOGS_CERTIFYCERTIFICATEDIALOG_H__
+#pragma once
 
 #include <QWizard>
 
@@ -32,14 +31,14 @@ public:
 
     bool exportableCertificationSelected() const;
 
-    bool trustCertificationSelected() const;
+    bool trustSignatureSelected() const;
+    QString trustSignatureDomain() const;
 
     bool nonRevocableCertificationSelected() const;
 
     void setSelectedUserIDs(const std::vector<GpgME::UserID> &uids);
     std::vector<unsigned int> selectedUserIDs() const;
 
-    void setCertificatesWithSecretKeys(const std::vector<GpgME::Key> &keys);
     GpgME::Key selectedSecretKey() const;
 
     bool sendToServer() const;
@@ -50,11 +49,15 @@ public:
 
     QString tags() const;
 
+    QDate expirationDate() const;
+
+public Q_SLOTS:
+    void accept() override;
+
 private:
     CertifyWidget *mCertWidget;
 };
 
 }
 
-#endif /* __KLEOPATRA_DIALOGS_CERTIFYCERTIFICATEDIALOG_H__ */
 
