@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEO_ASSUAN_H__
-#define __KLEO_ASSUAN_H__
+#pragma once
 
 #ifndef _ASSUAN_ONLY_GPG_ERRORS
 #define _ASSUAN_ONLY_GPG_ERRORS
@@ -35,7 +34,7 @@ typedef void *assuan_fd_t;
 #define ASSUAN_INT2FD(s)  ((void *)(s))
 #define ASSUAN_FD2INT(h)  ((unsigned int)(h))
 #else
-typedef int assuan_fd_t;
+using assuan_fd_t = int;
 #define ASSUAN_INVALID_FD (-1)
 #define ASSUAN_INT2FD(s)  ((s))
 #define ASSUAN_FD2INT(h)  ((h))
@@ -45,4 +44,3 @@ typedef int assuan_fd_t;
  */
 #endif
 
-#endif /* __KLEOPATRA_ASSUAN_H__ */
