@@ -6,8 +6,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef __KLEOPATRA_SMARTCARD_DEVICEINFOWATCHER_P_H__
-#define __KLEOPATRA_SMARTCARD_DEVICEINFOWATCHER_P_H__
+#pragma once
 
 #include <gpgme++/interfaces/statusconsumer.h>
 
@@ -17,6 +16,8 @@
 
 #include <QThread>
 
+#include <memory>
+
 namespace Kleo
 {
 
@@ -60,4 +61,3 @@ private:
 
 }
 
-#endif // __KLEOPATRA_SMARTCARD_DEVICEINFOWATCHER_P_H__
