@@ -84,7 +84,7 @@ private:
     void slotSetInitialPin()
     {
         if (!firstCardWithNullPin.empty()) {
-            SetInitialPinCommand *cmd = new SetInitialPinCommand(firstCardWithNullPin);
+            auto cmd = new SetInitialPinCommand(firstCardWithNullPin);
             q->setAttentionWindow(cmd->dialog());
             startCommand(cmd);
         }
@@ -92,7 +92,7 @@ private:
 
     void slotLearnCertificates()
     {
-        LearnCardKeysCommand *cmd = new LearnCardKeysCommand(GpgME::CMS);
+        auto cmd = new LearnCardKeysCommand(GpgME::CMS);
         q->setAttentionWindow(cmd->dialog());
         startCommand(cmd);
     }
@@ -140,7 +140,7 @@ SysTrayIcon::Private::Private(SysTrayIcon *qq)
       aboutDialog()
 {
     q->setNormalIcon(QIcon::fromTheme(QStringLiteral("kleopatra")));
-    q->setAttentionIcon(QIcon::fromTheme(QStringLiteral("secure-card")));
+    q->setAttentionIcon(QIcon::fromTheme(QStringLiteral("auth-sim-locked")));
 
     KDAB_SET_OBJECT_NAME(menu);
     KDAB_SET_OBJECT_NAME(openCertificateManagerAction);
