@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UISERVER_ASSUANCOMMAND_H__
-#define __KLEOPATRA_UISERVER_ASSUANCOMMAND_H__
+#pragma once
 
 #include <utils/pimpl_ptr.h>
 #include <utils/types.h>
@@ -330,7 +329,7 @@ public:
 #ifndef HAVE_ASSUAN2
     typedef int(*_Handler)(assuan_context_s *, char *);
 #else
-    typedef gpg_error_t(*_Handler)(assuan_context_s *, char *);
+    using _Handler = gpg_error_t (*)(assuan_context_s *, char *);
 #endif
     virtual _Handler _handler() const = 0;
 
@@ -384,4 +383,3 @@ protected:
 
 }
 
-#endif /* __KLEOPATRA_UISERVER_ASSUANCOMMAND_H__ */
