@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UISERVER_ASSUANSERVERCONNECTION_H__
-#define __KLEOPATRA_UISERVER_ASSUANSERVERCONNECTION_H__
+#pragma once
 
 #include <QObject>
 
@@ -48,4 +47,3 @@ private:
 
 }
 
-#endif /* __KLEOPATRA_UISERVER_ASSUANSERVERCONNECTION_H__ */
