@@ -171,9 +171,9 @@ void DecryptVerifyCommandFilesBase::doCanceled()
 
 void DecryptVerifyCommandFilesBase::Private::slotProgress(const QString &what, int current, int total)
 {
-    Q_UNUSED(what);
-    Q_UNUSED(current);
-    Q_UNUSED(total);
+    Q_UNUSED(what)
+    Q_UNUSED(current)
+    Q_UNUSED(total)
     // ### FIXME report progress, via sendStatus()
 }
 
