@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEO_UISERVER_SIGNENCRYPTFILESCOMMAND_H__
-#define __KLEO_UISERVER_SIGNENCRYPTFILESCOMMAND_H__
+#pragma once
 
 #include "assuancommand.h"
 
@@ -94,4 +93,3 @@ public:
 
 }
 
-#endif /*__KLEO_UISERVER_SIGNENCRYPTFILESCOMMAND_H__*/
