@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UISERVER_UISERVER_H__
-#define __KLEOPATRA_UISERVER_UISERVER_H__
+#pragma once
 
 #include <QObject>
 
@@ -59,4 +58,3 @@ private:
 
 }
 
-#endif /* __KLEOPATRA_UISERVER_UISERVER_H__ */
