@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_VIEW_KEYTREEVIEW_H__
-#define __KLEOPATRA_VIEW_KEYTREEVIEW_H__
+#pragma once
 
 #include <QWidget>
 
@@ -157,4 +156,3 @@ private:
 
 }
 
-#endif // __KLEOPATRA_VIEW_KEYTREEVIEW_H__
